@@ -17,8 +17,7 @@ fdt.default <-
       start <- tmp[1] - abs(tmp[1])/100
       end   <- tmp[2] + abs(tmp[2])/100
       R     <- end - start
-      h     <- R/k
-    }
+      h     <- R/k}
 
     # User defines 'x' and 'k'
     else if (missing(start) && missing(end) && missing(h)) {
@@ -27,8 +26,7 @@ fdt.default <-
       start <- tmp[1] - abs(tmp[1])/100
       end   <- tmp[2] + abs(tmp[2])/100
       R     <- end - start
-      h     <- R/abs(k)
-    }
+      h     <- R/abs(k)}
 
     # User defines 'x', 'start' and 'end'
     else if (missing(k) && missing(h)) {
@@ -37,13 +35,11 @@ fdt.default <-
       R   <- end - start
       k   <- sqrt(abs(R))
       if (k < 5) k = 5 # min value of k
-      h   <- R/k
-    }
+      h   <- R/k}
 
     # User defines 'x', 'start', 'end' and 'h'
     else if (missing(k)) {
-      stopifnot(length(start) >= 1, length(end) >= 1, length(h) >= 1)
-    }
+      stopifnot(length(start) >= 1, length(end) >= 1, length(h) >= 1)}
 
     else stop('Please, see the function sintax!')
 
