@@ -15,8 +15,7 @@ make.fdt.multiple <-
       start <- tmp[1] - abs(tmp[1])/100
       end   <- tmp[2] + abs(tmp[2])/100
       R     <- end - start
-      h     <- R/k
-    }
+      h     <- R/k}
 
     # User defines 'x' and 'k'
     else {
@@ -24,8 +23,7 @@ make.fdt.multiple <-
       start <- tmp[1] - abs(tmp[1])/100
       end   <- tmp[2] + abs(tmp[2])/100
       R     <- end - start
-      h     <- R/abs(k)
-    }
+      h     <- R/abs(k)}
 
     fdt <- make.fdt.simple(x, start, end, h, right)
     breaks <- c(start, end, h, ifelse (right, 1, 0))
