@@ -1,8 +1,8 @@
 summary.fdt.multiple <-
   function (object, columns=1:6, round=2, format.classes=FALSE,
-            pattern='%09.3e', ...)
+            pattern='%09.3e', row.names=FALSE, right=TRUE, Sweave=FALSE, ...)
   {
-    right  <- as.logical(object[[1]][['breaks']]['right'])
+    right.tmp  <- as.logical(object[[1]][['breaks']]['right'])
     tnames <- names(object)
     for (i in 1:length(tnames)) {
       res <- object[tnames[i]][[tnames[i]]][['table']]
@@ -10,11 +10,12 @@ summary.fdt.multiple <-
       cat(tnames[i], '\n')
       if (format.classes) {
         tmp      <- as.character(res[, 1])
-        res[, 1] <- make.fdt.format.classes(tmp, right, pattern)
-      }
+        res[, 1] <- make.fdt.format.classes(tmp, right.tmp, pattern)}
       names(res) <- c('Class limits', 'f', 'rf', 'rf(%)', 'cf', 'cf(%)')[columns]
-      print(res, row.names=FALSE)
-      cat('\n')
-    }
+      if(Sweave)
+        invisible(res)
+      else
+        print.data.frame(res, row.names=row.names, right=right, ...)
+      cat('\n')}
   }
 
